@@ -121,6 +121,10 @@ namespace Oxygen
             Gtk::gtk_notebook_get_tabbar_rect( GTK_NOTEBOOK( _target ), &updateRect );
             Gtk::gtk_widget_queue_draw( _target, &updateRect );
 
+            #if OXYGEN_DEBUG
+            std::cerr << "Oxygen::TabWidgetData::setDirty - update: " << updateRect << std::endl;
+            #endif
+
         }
 
     }
@@ -207,7 +211,6 @@ namespace Oxygen
             // allocate new ChildData
             ChildData data;
             data._destroyId.connect( G_OBJECT(widget), "destroy", G_CALLBACK( childDestroyNotifyEvent ), this );
-            data._styleChangeId.connect( G_OBJECT(widget), "style-set", G_CALLBACK( childStyleChangeNotifyEvent ), this );
             data._enterId.connect( G_OBJECT(widget), "enter-notify-event", G_CALLBACK( childCrossingNotifyEvent ), this );
             data._leaveId.connect( G_OBJECT(widget), "leave-notify-event", G_CALLBACK( childCrossingNotifyEvent ), this );
 
@@ -258,10 +261,6 @@ namespace Oxygen
         return FALSE;
     }
 
-    //____________________________________________________________________________________________
-    void TabWidgetData::childStyleChangeNotifyEvent( GtkWidget* widget, GtkStyle*, gpointer data )
-    { static_cast<TabWidgetData*>(data)->unregisterChild( widget ); }
-
     //____________________________________________________________________________________________
     void TabWidgetData::childAddedEvent( GtkContainer* parent, GtkWidget*, gpointer data )
     {
@@ -285,7 +284,6 @@ namespace Oxygen
     {
 
         _destroyId.disconnect();
-        _styleChangeId.disconnect();
         _enterId.disconnect();
         _leaveId.disconnect();
         _addId.disconnect();
